pub struct ParsingMap<Name, Value, Index> { /* private fields */ }Implementations
Sourceimpl<Name: Ord, Value, Index: Id> ParsingMap<Name, Value, Index>
impl<Name: Ord, Value, Index: Id> ParsingMap<Name, Value, Index>
pub fn new() -> Self
pub fn builtin(&mut self, name: Name, range: Range<usize>, value: Value)
Sourcepub fn insert<'input, 'a, E>(
&'a mut self,
name: Once<Name>,
element: &Node<'input, 'input>,
errors: &mut Vec<E>,
) -> Option<ParsingEntry<'a, Name, Value, Index>>where
E: From<ParseError>,
pub fn insert<'input, 'a, E>(
&'a mut self,
name: Once<Name>,
element: &Node<'input, 'input>,
errors: &mut Vec<E>,
) -> Option<ParsingEntry<'a, Name, Value, Index>>where
E: From<ParseError>,
Insert named item into collection.
Raise an error if the element is missing a name.
Raise an error if there is a duplicate.
Return a mutable reference to the inserted item’s value.
The value is an Option<T> with a default of None.
Sourcepub fn insert_derived<'input, 'a, E>(
&'a mut self,
element_name: &str,
name: Name,
name_range: Range<usize>,
errors: &mut Vec<E>,
) -> Option<ParsingEntry<'a, Name, Value, Index>>where
E: From<ParseError>,
pub fn insert_derived<'input, 'a, E>(
&'a mut self,
element_name: &str,
name: Name,
name_range: Range<usize>,
errors: &mut Vec<E>,
) -> Option<ParsingEntry<'a, Name, Value, Index>>where
E: From<ParseError>,
Insert derived item into collection.
Raise an error if there is a duplicate.
Return a mutable reference to the inserted item’s value.
The value is an Option<T> with a default of None.
Sourcepub fn collect(self) -> Option<ParsedMap<Name, Value, Index>>where
Name: Clone,
pub fn collect(self) -> Option<ParsedMap<Name, Value, Index>>where
Name: Clone,
Collect all parsed items in collection sorted by name.
Return None if any where invalid.
Sourcepub fn collect_by_index(self) -> Option<ParsedMap<Name, Value, Index>>
pub fn collect_by_index(self) -> Option<ParsedMap<Name, Value, Index>>
Collect all parsed items in collection sorted by occurance (index).
Return None if any where invalid.
Sourcepub fn collect_by_key<Key, F>(
self,
key: F,
) -> Option<ParsedMap<Name, Value, Index>>
pub fn collect_by_key<Key, F>( self, key: F, ) -> Option<ParsedMap<Name, Value, Index>>
Collect all parsed items in collection sorted by function.
Return None if any where invalid.
Sourcepub fn collect_to_btree(self) -> Option<BTreeMap<Name, Value>>where
Name: Clone,
pub fn collect_to_btree(self) -> Option<BTreeMap<Name, Value>>where
Name: Clone,
Collect all parsed items in collection to a b-tree
Return None if any where invalid.